import * as cdk from 'aws-cdk-lib';
import * as constructs from 'constructs';
/**
 * A resource provider for Aqua Enterprise Enforcer.
 *
 * @schema CfnEnforcerProps
 */
export interface CfnEnforcerProps {
    /**
     * EKS cluster name
     *
     * @schema CfnEnforcerProps#ClusterID
     */
    readonly clusterId?: string;
    /**
     * Secrets Manager ARN for kubeconfig file
     *
     * @schema CfnEnforcerProps#KubeConfig
     */
    readonly kubeConfig?: string;
    /**
     * IAM to use with EKS cluster authentication, if not resource execution role will be used
     *
     * @schema CfnEnforcerProps#RoleArn
     */
    readonly roleArn?: string;
    /**
     * Namespace to use with helm. Created if doesn't exist and default will be used if not provided
     *
     * @schema CfnEnforcerProps#Namespace
     */
    readonly namespace?: string;
    /**
     * Name for the helm release
     *
     * @schema CfnEnforcerProps#Name
     */
    readonly name?: string;
    /**
     * Custom Values can optionally be specified
     *
     * @schema CfnEnforcerProps#Values
     */
    readonly values?: any;
    /**
     * String representation of a values.yaml file
     *
     * @schema CfnEnforcerProps#ValueYaml
     */
    readonly valueYaml?: string;
    /**
     * Version can be specified, if not latest will be used
     *
     * @schema CfnEnforcerProps#Version
     */
    readonly version?: string;
    /**
     * Custom Value Yaml file can optionally be specified
     *
     * @schema CfnEnforcerProps#ValueOverrideURL
     */
    readonly valueOverrideUrl?: string;
    /**
     * Timeout for resource provider. Default 60 mins
     *
     * @schema CfnEnforcerProps#TimeOut
     */
    readonly timeOut?: number;
    /**
     * For network connectivity to Cluster inside VPC
     *
     * @schema CfnEnforcerProps#VPCConfiguration
     */
    readonly vpcConfiguration?: CfnEnforcerPropsVpcConfiguration;
}
/**
 * Converts an object of type 'CfnEnforcerProps' to JSON representation.
 */
export declare function toJson_CfnEnforcerProps(obj: CfnEnforcerProps | undefined): Record<string, any> | undefined;
/**
 * For network connectivity to Cluster inside VPC
 *
 * @schema CfnEnforcerPropsVpcConfiguration
 */
export interface CfnEnforcerPropsVpcConfiguration {
    /**
     * Specify one or more security groups
     *
     * @schema CfnEnforcerPropsVpcConfiguration#SecurityGroupIds
     */
    readonly securityGroupIds?: string[];
    /**
     * Specify one or more subnets
     *
     * @schema CfnEnforcerPropsVpcConfiguration#SubnetIds
     */
    readonly subnetIds?: string[];
}
/**
 * Converts an object of type 'CfnEnforcerPropsVpcConfiguration' to JSON representation.
 */
export declare function toJson_CfnEnforcerPropsVpcConfiguration(obj: CfnEnforcerPropsVpcConfiguration | undefined): Record<string, any> | undefined;
/**
 * A CloudFormation `Aqua::Enterprise::Enforcer`
 *
 * @cloudformationResource Aqua::Enterprise::Enforcer
 * @stability external
 * @link https://github.com/aquasecurity/aqua-helm.git
 */
export declare class CfnEnforcer extends cdk.CfnResource {
    /**
    * The CloudFormation resource type name for this resource class.
    */
    static readonly CFN_RESOURCE_TYPE_NAME = "Aqua::Enterprise::Enforcer";
    /**
     * Resource props.
     */
    readonly props: CfnEnforcerProps;
    /**
     * Attribute `Aqua::Enterprise::Enforcer.ID`
     * @link https://github.com/aquasecurity/aqua-helm.git
     */
    readonly attrId: string;
    /**
     * Create a new `Aqua::Enterprise::Enforcer`.
     *
     * @param scope - scope in which this resource is defined
     * @param id    - scoped id of the resource
     * @param props - resource properties
     */
    constructor(scope: constructs.Construct, id: string, props: CfnEnforcerProps);
}
